@@ -284,7 +284,8 @@ extendBuildDepends targetDir binToDeb ourBins buildDeps = (buildDeps ++) <$> con
                            then do
                              let debFile = targetDir </> dep
                              need [debFile]
-                             Stdout depList <- cmd [ "dpkg-deb"
+                             Stdout depList <- cmd (Traced "")
+                                                   [ "dpkg-deb"
                                                    , "--field"
                                                    , debFile
                                                    , "Depends"
